*-------------------------------------------------------------------------------------*
* Configuration                                                                       *
* ------------------------------------------------------------------------------------*

*-------------------------------- specify your paths here! ---------------------------*

* Set path to working directory
global dir 			"_SET_PATH_HERE_"

* Set path to SOEP data (soep-long, v31-1)
global soep			"_SET_PATH_HERE_"

*-------------------------------------------------------------------------------------*

global data			"${dir}/02_data"
global tables		"${dir}/03_tables"
global graphs 		"${dir}/04_graphs"


*-------------------------------------------------------------------------------------*
*-------------------------------------------------------------------------------------*


*-------------------------------------------------------------------------------------*
* Select variables                                                                    *
* ------------------------------------------------------------------------------------*

* Main person file
use "$soep/pl.dta", clear
keep pid syear hid						/// person ID, survey year, household ID  
     plh0182         					/// life satisfaction (outcome measure)
	 plb0021         					/// registered as unemployed
	 plj0006       	 					/// ethnic Germans
	 pli0043 pli0041 		 			/// housework hours
     pli0098 pli0171   					/// church attendance   
	 plb0304 							/// reasons for losing job
	 ple0008							//  self-rated health
  
* Merge from bio
merge 1:1 pid syear using "$soep/bio.dta", 	///
	keepusing (l0020)              			/// status upon immigration
	keep (1 3) nogen

* Merge from pgen
merge 1:1 pid syear using  "$soep/pgen.dta", ///
	keepusing (pgfamstd          	/// marital status
			   pgemplst			 	/// employment status
			   pgcasmin)     	 	/// education    
	keep (1 3) nogen
			   
* Merge from ppfad
merge m:1 pid using "$soep/ppfad.dta", ///
	keepusing (letztbef            	/// year of last interview
	           gebjahr sex          /// year of birth, gender
			   loc1989             	/// where lived before German reunification
			   corigin             	/// country of origin
			   migback             	/// migration background
			   psample)            	/// SOEP starting sample
	keep (1 3) nogen
			   
* Merge from pequiv
merge 1:1 pid syear using "$soep/pequiv.dta", ///
	keepusing (d11106 			   	/// number of persons in the household
			   i11102 			   	/// post-government income
			   h11101  	   			/// children in household
			   y11101)			   	/// price index
	keep(1 3) nogen

* Merge from ppfadl
merge 1:1 pid syear using "$soep\ppfadl.dta", ///
	keepusing (partner) 			/// partner in household
	keep (1 3) nogen
		
* Merge from hgen
merge m:1 hid syear using "$soep/hgen.dta", ///
	keepusing (hgowner hgsize) 		/// homeownership, size of living unit   
	keep(1 3) nogen
	
* Merge soep from pbr_exit
preserve
	use "$soep/pbr_exit.dta", clear
	duplicates drop pid, force
	save "$data/dropout.dta", replace
restore
merge m:1 pid using "$data/dropout.dta", ///
	keepusing (ypergz) 				/// reasons for dropout   
	keep(1 3) nogen
erase "$data/dropout.dta"
	
* Merge period data
merge m:1 syear using "$data/period.dta", nogen

* Set label language to English
label language EN


*-------------------------------------------------------------------------------------*
* Restrict sample (survey year, age, immigrant status                                 *
*-------------------------------------------------------------------------------------*

* Delete observations before 1990
drop if syear < 1990

* Select age range 20 - 64
gen age = syear - gebjahr
keep if age > 19 & age < 65

* Drop respondents without valid information on immigrant indicator
drop if migback == -1


*-------------------------------------------------------------------------------------*
* Income and education (generate before dropping further cases/observations)          *
*-------------------------------------------------------------------------------------*

* Equivalise post-government household income (square root scale)
replace i11102 = . if i11102 < 0
gen einc = i11102 / (d11106^0.5)
	
* Weight by consumer price index
replace y11101 = . if y11101 < 0		
gen eincp = einc * (100/y11101)
replace eincp = . if eincp < 2000 // set implausible values to missing

* Calculate percent of year-specific median income
gen pmi = .
forvalues x = 1990/2014 {
	sum eincp if syear == `x', d
	replace pmi = eincp/r(p50) if syear == `x'
	}
*
recode pmi (0/.50    = 1 "< 50%"      ) ///
		   (.50/.75  = 2 "50% - 75%"  ) ///
		   (.75/1    = 3 "75% - 100%" ) ///
		   (1/1.25   = 4 "100% - 125%") ///
		   (1.25/1.5 = 5 "125% - 150%") ///
		   (1.5/100  = 6 "> 150%"     ) ///
		   (.        = 7 "Missing"    ) ///
	, gen(pmic)
label variable pmic "Percent of median income (categorical)"

* Education
bysort pid (syear): egen ed = max(pgcasmin)
replace ed = . if ed < 1
recode 	ed  				    ///
		(1 2 4   = 1 "Lower")			///
		(3 5 6   = 2 "Intermediate")	///
		(7 8 9   = 3 "Higher")			///
		(. = .)							///
		, gen(edu)


*-------------------------------------------------------------------------------------*
* Unemployment          															  *
*-------------------------------------------------------------------------------------*

* Initial observation in unemployment
gen unemployed = plb0021 == 1
	label variable unemployed "Registered as unemployed"
	gen aux = syear if unemployed == 1 
	bysort pid (syear): egen aux1 = min(aux) 				
	// aux1: minimum value of syear (i.e. earliest observation in unemployment)
gen ue = 0									
	replace ue = 1 if aux == aux1 & aux!=. 			
	label variable ue "Initial observation in unemployment"
	drop aux aux1
gen aux = syear if ue == 1 
	bysort pid (syear): egen yue = max(aux) // year of unemployment
	label variable yue "Year of initial observation in unemployment"
drop aux

* Mark last observation before transition
gen aux = syear if ue == 1
	replace aux = aux - 1 // Survey year before the initial transition
	bysort pid: egen aux1 = max(aux)
gen before = aux1 == syear
	label variable before "Year before unemployment"
	drop aux aux1

* Mark second-last observation before transition
gen aux = syear if ue == 1
	replace aux = aux - 2 // Survey year before the initial transition
	bysort pid: egen aux1 = max(aux)
gen before2 = aux1 == syear
	label variable before2 "2 Years before unemployment"
	drop aux aux1

* Drop respondents not observed in the year before initial obs. in unemployment
bysort pid: egen aux = max(ue)
bysort pid: egen aux1 = max(before)
drop if aux == 1 & aux1 != 1
	drop aux aux1

* Drop respondents entering unemployment out of a status "not employed"
gen aux = before == 1 & pgemplst == 5
bysort pid: egen aux1 = max(aux) 	
drop if aux1 == 1
	drop aux aux1

* Define event sample indicator
bysort pid: egen event = max(ue)

* Delete repeated transitions to unemployment
gen aux = (event == 1 & syear > yue & unemployed == 0)
	// 1 if experienced transition but no longer observed in unemployment
gen aux1 = syear if aux == 1
bysort pid: egen aux2 = min(aux1)
	// aux2: first survey year in which no longer unemployed
gen aux3 = unemployed == 1 & syear > aux2
	// aux3 indicates observations in unemployment after initial unemployment has ended
gen aux4 = syear if aux3 == 1
bysort pid: egen aux5 = min(aux4)
	// aux5 is the year of the first repeated transition to unemployment
drop if event == 1 & syear >= aux5
	drop aux aux?

* Ensure that observations in unemployment are continuous
bysort pid (syear): gen n = _n
gen aux = n if ue == 1
bysort pid (syear): egen aux1 = max(aux)
gen n1 = n - aux1 // n1 is 0 in the year of the transition and counts upward from that year
	drop aux aux1
gen aux = syear - yue if unemployed == 1
drop if unemployed == 1 & n1 != aux
	drop aux n1

* Calculate unemployment duration for event sample
bysort pid: egen dur_ue = sum(unemployed)

	
*-------------------------------------------------------------------------------------*
* Define observation markers                                                       	  *
*-------------------------------------------------------------------------------------*
	
* Mark consecutive observations in unemployment
gen index = syear - yue
label variable index "Years before/after transition to unemployment"
replace index = . if index > 0 & unemployed != 1

* Generate time variable without leads; for main analysis
recode index 				///
		(-24/-1 = 0 "0") 	///
		(0      = 1 "0-1") 	///
		(1      = 2 "1-2") 	///
		(2/17   = 3 "> 2") 	///
	, gen(time)
label variable time "Years in unemployment"
replace time = 0 if time == .

* Generate time variable with leads; for supplement
recode index 					///
		(-24/-3 = 0 "< -2") 	///
		(-2     = 1 "-2/-1") 	///	
		(-1     = 2 "-1/0") 	///		
		(0      = 3 "0/1") 		///
		(1      = 4 "1/2") 		///
		(2/17   = 5 "> 2") 		///
	, gen(time1)
label variable time1 "Years in unemployment"
replace time1 = 0 if time1 == .


*-------------------------------------------------------------------------------------*
* Prepare analytic variables							     			          	  *
*-------------------------------------------------------------------------------------*

* Outcome
gen ls = plh0182 
replace ls = . if ls < 0
label variable ls "Global life satisfaction (0-10)"

* Immigrant status
gen mig = migback != 1
label variable mig "Immigrant"

* Immigrant groups
bysort pid (syear): egen imstat = max(l0020)
bysort pid (syear): egen germdesc = max(plj0006)
gen ethnic_german =  imstat == 1 | germdesc == 1 
recode corigin  									///
(1 = 1 "Germany") 									///
(2 = 2 "Turkey") 									///
(3 4 5 6 = 3 "Other countries of recruitment")      ///
(32 74 77 78 97 97 130 132 148 141 82 = 4 "FSU")   	///
(21 26 29 31 73 101 22 103 119 140 146 120 121 122 123 222 165 = 5 "Eastern Europe") /// 
(10/17 19 = 6 "Western EU") ///
(-3 / -1 =. ) 				/// 
(nonmiss = 7 "Other") 		///
 , gen (origin_group)
replace origin_group = 8 if ethnic_german == 1
replace origin_group = 9 if migback == 3
	drop imstat germdesc ethnic_german
label define origin 		///
	1 "Native German"  		///
	2 "Turkey" 				///
	3 "Other countries of recruitment" ///
	4 "FSU (excluding ethnic Germans)" ///
	5 "Eastern Europe" 		///
	6 "Western Europe" 		///
	7 "Other" 				///
	8 "Ethnic German" 		///
	9 "Second generation", replace
label val origin_group origin 
label variable origin_group "Country of origin (grouped)"

* Gender 
gen male = sex == 1
label variable male "Male"

* Reasons for unemployment
clonevar aux = plb0304 if ue == 1
bysort pid (syear): egen reason = max(aux)
	drop aux
recode reason 							///
		(3 = 1 "Fired") 				///
		(1 8 = 2 "Company closed")		///
		(2 4 5 6 7 9 10 11 12 13 = 0 "Other reasons") 	///
		(-2 -3 = 3 "Unknown")			/// 
		(-1 = 4 "Refusal") 				///
	, gen(why)
replace why = 0 if why == .

* Church attendance
clonevar relig = pli0098
replace relig = . if relig < 0
replace relig = 1 if relig == . & inlist(pli0171,1,2)
replace relig = 2 if relig == . & inlist(pli0171,3)
replace relig = 3 if relig == . & inlist(pli0171,4)
replace relig = 4 if relig == . & inlist(pli0171,5)
** Define before unemployment
*** Start at the last observation before unemployment
gen aux = relig if before == 1 & event == 1
bysort pid: egen church = max(aux)
	drop aux
fre church if event & n == 1
*** If not available, take the second-last observation before unemployment
gen aux = relig if before2 == 1 & event == 1
bysort pid: egen aux1 = max(aux)
replace church = aux1 if church == . & aux1 != .
	drop aux aux1
fre church if event & n == 1
*** If not available, take the observation at unemployment
gen aux = relig if ue == 1 & event == 1
bysort pid: egen aux1 = max(aux)
replace church = aux1 if church == . & aux1 != .
	drop aux aux1
fre church if event & n == 1
*** Set control sample to zero (almost no missings in the event sample)
replace church = 0 if church == .
replace church = 0 if church == 4 // use never as reference

* Provider role: Kid under 15 
recode h11101 (0 = 0) (1/10 = 1), gen(child)
gen aux = child if before == 1
bysort pid: egen kid = max(aux)
	drop aux
replace kid = 0 if kid == . // set control sample to zero

* Married
gen married = inlist(pgfam,1,6,7,8)
gen aux = married if before == 1 & event == 1
bysort pid: egen mar = max(aux)
	drop aux
replace mar = 0 if mar == . // set control sample to zero

* Partner in household
gen par = partner > 0

* Education
gen aux = edu if before == 1 & event == 1
bysort pid: egen educ = max(aux)
	drop aux
replace educ = 0 if educ == . & event == 0 & edu != . // set control sample to zero

* Home owner
gen owner = hgowner == 1
gen aux = owner if before == 1 & event == 1
bysort pid: egen own = max(aux)
	drop aux
replace own = 0 if own == . & event == 0 & hgowner != . // set control sample to zero

* Traditional gender roles: Zero hours of routine housework
replace pli0043 = . if pli0043 < 0
replace pli0041 = . if pli0041 < 0
replace pli0043 = pli0041 if pli0043 == . & pli0041 != .
gen trad = .
replace trad = 1 if pli0043 == 0
replace trad = 0 if pli0043 != 0 & pli0043 != .
** Define for period before unnemployment
*** Start at the last observation before unemployment
gen aux = trad if before == 1 & event == 1
bysort pid: egen hw_trad = max(aux)
	drop aux
*** If not available, take the second last observation before unemployment
gen aux = trad if before2 == 1 & event == 1
bysort pid: egen aux1 = max(aux)
replace hw_trad = aux1 if hw_trad == . & aux1 != .
*** Flag for missings in the event sample
replace hw_trad = 2 if hw_trad == . & event == 1
*** Set control sample to zero
replace hw_trad = 0 if hw_trad == .
*** Set women to zero
replace hw_trad = 0 if hw_trad == 1 & male == 0
drop aux aux1

* Housing status
gen size = hgsize/d11106
gen size20 = size/20
center size20, gen(size_c)
gen aux = size20*size20
center aux, gen(size2_c)
	drop aux
replace size20 = 2 if size20 == . // replace by mean
replace size_c = 0 if size_c == .  
replace size2_c = 0 if size2_c == .

* Marital Status
recode pgfamstd 						///
	(1 6 -1 -3  -5 7 8 = 1 "Married") 	/// replace by mode
	(3      = 2 "Single") 				///
	(2 4    = 3 "Divorced") 			///
	(5      = 4 "Widowed")				///
  , gen(marstat)
label variable marstat "Marital status"
drop pgfamstd

* East German
gen east = loc1989 == 1

* Age at transition
gen aux = age if ue
bysort pid (syear): egen age_tr = max(aux)
	drop aux

* Center age
gen age2 = age*age
gen age3 = age*age*age
gen age4 = age*age*age*age
center age, gen(age_c)
center age2, gen(age2_c)
center age3, gen(age3_c)
center age4, gen(age4_c)

* Attrition
gen left = letztbef < 2014
replace left = 2 if ypergz == 50
replace left = 3 if ypergz == 60

* Self-rated health
replace ple0008 = . if ple0008 < 0
rename ple0008 srh


*-------------------------------------------------------------------------------------*
* Finishing touches							     			          	 			  *
*-------------------------------------------------------------------------------------*

* Restrict control sample to people who have no episodes of non-employment
gen aux = pgemplst == 5
bysort pid: egen aux1 = max(aux)
drop if event == 0 & aux1 == 1
	drop aux

* Keep only relevant variables
keep 	pid syear d11106 gdp age eincp pmi pmic edu unemployed ue yue before event before2 	///
		index time time1 ls mig origin_group male why church kid mar par own hw_trad dur_ue	///
		size size_c size2_c marstat left pgemp relig child married trad owner age_tr 		///
		age_c age2_c age3_c age4_c srh

		
*-------------------------------------------------------------------------------------*
*-------------------------------------------------------------------------------------*

* Save for analysis

order pid syear time
save "${data}/data", replace


*-------------------------------------------------------------------------------------*
*-------------------------------------------------------------------------------------*

